@@ -8,7 +8,6 @@ DEFINE_TEST(test_acl_platform_posix1e_read)
 DEFINE_TEST(test_acl_posix1e)
 DEFINE_TEST(test_acl_from_text)
 DEFINE_TEST(test_acl_to_text)
-DEFINE_TEST(test_ar_mode)
 DEFINE_TEST(test_archive_api_feature)
 DEFINE_TEST(test_archive_clear_error)
 DEFINE_TEST(test_archive_cmdline)
@@ -18,12 +17,11 @@ DEFINE_TEST(test_archive_sha1)
 DEFINE_TEST(test_archive_sha256)
 DEFINE_TEST(test_archive_sha384)
 DEFINE_TEST(test_archive_sha512)
-DEFINE_TEST(test_archive_getdate)
 DEFINE_TEST(test_archive_match_owner)
 DEFINE_TEST(test_archive_match_path)
 DEFINE_TEST(test_archive_match_time)
+DEFINE_TEST(test_archive_parse_date)
 DEFINE_TEST(test_archive_pathmatch)
-DEFINE_TEST(test_archive_read_ahead_eof)
 DEFINE_TEST(test_archive_read_add_passphrase)
 DEFINE_TEST(test_archive_read_add_passphrase_incorrect_sequance)
 DEFINE_TEST(test_archive_read_add_passphrase_single)
@@ -33,6 +31,7 @@ DEFINE_TEST(test_archive_read_add_passphrase_set_callback2)
 DEFINE_TEST(test_archive_read_add_passphrase_set_callback3)
 DEFINE_TEST(test_archive_read_add_passphrase_multiple_with_callback)
 DEFINE_TEST(test_archive_read_add_passphrase_multiple_with_callback2)
+DEFINE_TEST(test_archive_read_ahead_eof)
 DEFINE_TEST(test_archive_read_close_twice)
 DEFINE_TEST(test_archive_read_close_twice_open_fd)
 DEFINE_TEST(test_archive_read_close_twice_open_filename)
@@ -114,6 +113,7 @@ DEFINE_TEST(test_archive_write_set_option)
 DEFINE_TEST(test_archive_write_set_options)
 DEFINE_TEST(test_archive_write_set_passphrase)
 DEFINE_TEST(test_archive_write_set_passphrase_callback)
+DEFINE_TEST(test_ar_mode)
 DEFINE_TEST(test_bad_fd)
 DEFINE_TEST(test_compat_bzip2)
 DEFINE_TEST(test_compat_cpio)
@@ -222,13 +222,19 @@ DEFINE_TEST(test_read_format_7zip_ppmd)
 DEFINE_TEST(test_read_format_7zip_lzma2_arm64)
 DEFINE_TEST(test_read_format_7zip_deflate_arm64)
 DEFINE_TEST(test_read_format_7zip_win_attrib)
+DEFINE_TEST(test_read_format_7zip_sfx_pe)
+DEFINE_TEST(test_read_format_7zip_sfx_modified_pe)
+DEFINE_TEST(test_read_format_7zip_sfx_elf)
 DEFINE_TEST(test_read_format_7zip_extract_second)
+DEFINE_TEST(test_read_format_7zip_lzma2_riscv)
 DEFINE_TEST(test_read_format_7zip_lzma2_sparc)
 DEFINE_TEST(test_read_format_7zip_zstd_sparc)
 DEFINE_TEST(test_read_format_7zip_deflate_powerpc)
+DEFINE_TEST(test_read_format_7zip_lzma2_powerpc)
 DEFINE_TEST(test_read_format_7zip_encryption_data)
 DEFINE_TEST(test_read_format_7zip_encryption_header)
 DEFINE_TEST(test_read_format_7zip_encryption_partially)
+DEFINE_TEST(test_read_format_7zip_issue2765)
 DEFINE_TEST(test_read_format_7zip_malformed)
 DEFINE_TEST(test_read_format_7zip_packinfo_digests)
 DEFINE_TEST(test_read_format_ar)
@@ -236,15 +242,15 @@ DEFINE_TEST(test_read_format_cab)
 DEFINE_TEST(test_read_format_cab_filename)
 DEFINE_TEST(test_read_format_cpio_afio)
 DEFINE_TEST(test_read_format_cpio_afio_broken)
-DEFINE_TEST(test_read_format_cpio_bin)
-DEFINE_TEST(test_read_format_cpio_bin_Z)
 DEFINE_TEST(test_read_format_cpio_bin_be)
 DEFINE_TEST(test_read_format_cpio_bin_bz2)
+DEFINE_TEST(test_read_format_cpio_bin)
 DEFINE_TEST(test_read_format_cpio_bin_gz)
 DEFINE_TEST(test_read_format_cpio_bin_le)
 DEFINE_TEST(test_read_format_cpio_bin_lzip)
 DEFINE_TEST(test_read_format_cpio_bin_lzma)
 DEFINE_TEST(test_read_format_cpio_bin_xz)
+DEFINE_TEST(test_read_format_cpio_bin_Z)
 DEFINE_TEST(test_read_format_cpio_filename_eucJP_UTF8)
 DEFINE_TEST(test_read_format_cpio_filename_UTF8_eucJP)
 DEFINE_TEST(test_read_format_cpio_filename_UTF8_UTF8_jp)
@@ -263,9 +269,9 @@ DEFINE_TEST(test_read_format_cpio_filename_KOI8R_CP1251)
 DEFINE_TEST(test_read_format_cpio_filename_UTF8_CP1251)
 DEFINE_TEST(test_read_format_cpio_odc)
 DEFINE_TEST(test_read_format_cpio_svr4_bzip2_rpm)
+DEFINE_TEST(test_read_format_cpio_svr4c_Z)
 DEFINE_TEST(test_read_format_cpio_svr4_gzip)
 DEFINE_TEST(test_read_format_cpio_svr4_gzip_rpm)
-DEFINE_TEST(test_read_format_cpio_svr4c_Z)
 DEFINE_TEST(test_read_format_empty)
 DEFINE_TEST(test_read_format_gtar_filename_eucJP_UTF8)
 DEFINE_TEST(test_read_format_gtar_filename_CP866_KOI8R)
@@ -278,24 +284,25 @@ DEFINE_TEST(test_read_format_gtar_filename_CP866_CP1251_win)
 DEFINE_TEST(test_read_format_gtar_filename_KOI8R_CP1251)
 DEFINE_TEST(test_read_format_gtar_gz)
 DEFINE_TEST(test_read_format_gtar_lzma)
+DEFINE_TEST(test_read_format_gtar_redundant_L)
 DEFINE_TEST(test_read_format_gtar_sparse)
 DEFINE_TEST(test_read_format_gtar_sparse_length)
 DEFINE_TEST(test_read_format_gtar_sparse_skip_entry)
 DEFINE_TEST(test_read_format_huge_rpm)
-DEFINE_TEST(test_read_format_iso_Z)
-DEFINE_TEST(test_read_format_iso_multi_extent)
-DEFINE_TEST(test_read_format_iso_xorriso)
 DEFINE_TEST(test_read_format_isojoliet_bz2)
 DEFINE_TEST(test_read_format_isojoliet_long)
 DEFINE_TEST(test_read_format_isojoliet_rr)
 DEFINE_TEST(test_read_format_isojoliet_versioned)
+DEFINE_TEST(test_read_format_iso_multi_extent)
 DEFINE_TEST(test_read_format_isorr_bz2)
 DEFINE_TEST(test_read_format_isorr_ce)
 DEFINE_TEST(test_read_format_isorr_new_bz2)
 DEFINE_TEST(test_read_format_isorr_rr_moved)
+DEFINE_TEST(test_read_format_iso_xorriso)
+DEFINE_TEST(test_read_format_iso_Z)
 DEFINE_TEST(test_read_format_isozisofs_bz2)
-DEFINE_TEST(test_read_format_lha)
 DEFINE_TEST(test_read_format_lha_bugfix_0)
+DEFINE_TEST(test_read_format_lha)
 DEFINE_TEST(test_read_format_lha_filename)
 DEFINE_TEST(test_read_format_lha_filename_UTF16)
 DEFINE_TEST(test_read_format_mtree)
@@ -309,29 +316,6 @@ DEFINE_TEST(test_read_format_mtree_noprint)
 DEFINE_TEST(test_read_format_mtree_tab)
 DEFINE_TEST(test_read_format_mtree_crash747)
 DEFINE_TEST(test_read_format_pax_bz2)
-DEFINE_TEST(test_read_format_rar_set_format)
-DEFINE_TEST(test_read_format_rar_basic)
-DEFINE_TEST(test_read_format_rar_subblock)
-DEFINE_TEST(test_read_format_rar_noeof)
-DEFINE_TEST(test_read_format_rar_unicode_UTF8)
-DEFINE_TEST(test_read_format_rar_unicode_CP932)
-DEFINE_TEST(test_read_format_rar_compress_normal)
-DEFINE_TEST(test_read_format_rar_multi_lzss_blocks)
-DEFINE_TEST(test_read_format_rar_compress_best)
-DEFINE_TEST(test_read_format_rar_ppmd_lzss_conversion)
-DEFINE_TEST(test_read_format_rar_binary)
-DEFINE_TEST(test_read_format_rar_windows)
-DEFINE_TEST(test_read_format_rar_multivolume)
-DEFINE_TEST(test_read_format_rar_multivolume_w)
-DEFINE_TEST(test_read_format_rar_multivolume_skip)
-DEFINE_TEST(test_read_format_rar_sfx)
-DEFINE_TEST(test_read_format_rar_multivolume_stored_file)
-DEFINE_TEST(test_read_format_rar_multivolume_stored_file_skip)
-DEFINE_TEST(test_read_format_rar_multivolume_seek_data)
-DEFINE_TEST(test_read_format_rar_multivolume_seek_multiple_files)
-DEFINE_TEST(test_read_format_rar_multivolume_uncompressed_files)
-DEFINE_TEST(test_read_format_rar_ppmd_use_after_free)
-DEFINE_TEST(test_read_format_rar_ppmd_use_after_free2)
 DEFINE_TEST(test_read_format_rar5_set_format)
 DEFINE_TEST(test_read_format_rar5_stored)
 DEFINE_TEST(test_read_format_rar5_compressed)
@@ -370,6 +354,7 @@ DEFINE_TEST(test_read_format_rar5_truncated_huff)
 DEFINE_TEST(test_read_format_rar5_invalid_dict_reference)
 DEFINE_TEST(test_read_format_rar5_distance_overflow)
 DEFINE_TEST(test_read_format_rar5_nonempty_dir_stream)
+DEFINE_TEST(test_read_format_rar5_nonempty_dir_data)
 DEFINE_TEST(test_read_format_rar5_fileattr)
 DEFINE_TEST(test_read_format_rar5_different_window_size)
 DEFINE_TEST(test_read_format_rar5_window_buf_and_size_desync)
@@ -382,6 +367,35 @@ DEFINE_TEST(test_read_format_rar5_decode_number_out_of_bounds_read)
 DEFINE_TEST(test_read_format_rar5_bad_window_size_in_multiarchive_file)
 DEFINE_TEST(test_read_format_rar5_read_data_block_uninitialized_offset)
 DEFINE_TEST(test_read_format_rar5_data_ready_pointer_leak)
+DEFINE_TEST(test_read_format_rar5_only_crypt_exfld)
+DEFINE_TEST(test_read_format_rar5_only_unsupported_exfld)
+DEFINE_TEST(test_read_format_rar5_invalidhash_and_validhtime_exfld)
+DEFINE_TEST(test_read_format_rar_set_format)
+DEFINE_TEST(test_read_format_rar_basic)
+DEFINE_TEST(test_read_format_rar_subblock)
+DEFINE_TEST(test_read_format_rar_noeof)
+DEFINE_TEST(test_read_format_rar_unicode_UTF8)
+DEFINE_TEST(test_read_format_rar_unicode_CP932)
+DEFINE_TEST(test_read_format_rar_compress_normal)
+DEFINE_TEST(test_read_format_rar_multi_lzss_blocks)
+DEFINE_TEST(test_read_format_rar_compress_best)
+DEFINE_TEST(test_read_format_rar_ppmd_lzss_conversion)
+DEFINE_TEST(test_read_format_rar_binary)
+DEFINE_TEST(test_read_format_rar_windows)
+DEFINE_TEST(test_read_format_rar_multivolume)
+DEFINE_TEST(test_read_format_rar_multivolume_w)
+DEFINE_TEST(test_read_format_rar_multivolume_skip)
+DEFINE_TEST(test_read_format_rar_sfx)
+DEFINE_TEST(test_read_format_rar_multivolume_stored_file)
+DEFINE_TEST(test_read_format_rar_multivolume_stored_file_skip)
+DEFINE_TEST(test_read_format_rar_multivolume_seek_data)
+DEFINE_TEST(test_read_format_rar_multivolume_seek_multiple_files)
+DEFINE_TEST(test_read_format_rar_multivolume_uncompressed_files)
+DEFINE_TEST(test_read_format_rar_endarc_huge)
+DEFINE_TEST(test_read_format_rar_ppmd_use_after_free)
+DEFINE_TEST(test_read_format_rar_ppmd_use_after_free2)
+DEFINE_TEST(test_read_format_rar_newsub_huge)
+DEFINE_TEST(test_read_format_rar_symlink_huge)
 DEFINE_TEST(test_read_format_rar4_encrypted)
 DEFINE_TEST(test_read_format_rar4_encrypted_filenames)
 DEFINE_TEST(test_read_format_rar4_solid_encrypted)
@@ -395,6 +409,7 @@ DEFINE_TEST(test_read_format_rar_encryption_header)
 DEFINE_TEST(test_read_format_rar_encryption_partially)
 DEFINE_TEST(test_read_format_rar_filter)
 DEFINE_TEST(test_read_format_rar_invalid1)
+DEFINE_TEST(test_read_format_rar_overflow)
 DEFINE_TEST(test_read_format_raw)
 DEFINE_TEST(test_read_format_tar)
 DEFINE_TEST(test_read_format_tar_concatenated)
@@ -403,7 +418,11 @@ DEFINE_TEST(test_read_format_tar_empty_pax)
 DEFINE_TEST(test_read_format_tar_empty_with_gnulabel)
 DEFINE_TEST(test_read_format_tar_filename)
 DEFINE_TEST(test_read_format_tar_invalid_pax_size)
+DEFINE_TEST(test_read_format_tar_mac_metadata)
+DEFINE_TEST(test_read_format_tar_pax_g_large)
 DEFINE_TEST(test_read_format_tar_pax_large_attr)
+DEFINE_TEST(test_read_format_tar_pax_negative_time)
+DEFINE_TEST(test_read_format_tar_V_negative_size)
 DEFINE_TEST(test_read_format_tbz)
 DEFINE_TEST(test_read_format_tgz)
 DEFINE_TEST(test_read_format_tlz)
@@ -411,9 +430,11 @@ DEFINE_TEST(test_read_format_txz)
 DEFINE_TEST(test_read_format_tz)
 DEFINE_TEST(test_read_format_ustar_filename)
 DEFINE_TEST(test_read_format_warc)
+DEFINE_TEST(test_read_format_warc_incomplete)
 DEFINE_TEST(test_read_format_xar)
 DEFINE_TEST(test_read_format_xar_duplicate_filename_node)
 DEFINE_TEST(test_read_format_xar_doublelink)
+DEFINE_TEST(test_read_format_zip_utf8_paths)
 DEFINE_TEST(test_read_format_zip)
 DEFINE_TEST(test_read_format_zip_ppmd_one_file)
 DEFINE_TEST(test_read_format_zip_ppmd_one_file_blockread)
@@ -441,7 +462,6 @@ DEFINE_TEST(test_read_format_zip_lzma_stream_end)
 DEFINE_TEST(test_read_format_zip_lzma_stream_end_blockread)
 DEFINE_TEST(test_read_format_zip_7z_lzma)
 DEFINE_TEST(test_read_format_zip_7z_deflate)
-DEFINE_TEST(test_read_format_zip_utf8_paths)
 DEFINE_TEST(test_read_format_zip_comment_stored)
 DEFINE_TEST(test_read_format_zip_encryption_data)
 DEFINE_TEST(test_read_format_zip_encryption_header)
@@ -486,6 +506,7 @@ DEFINE_TEST(test_read_format_zip_with_invalid_traditional_eocd)
 DEFINE_TEST(test_read_format_zip_zip64a)
 DEFINE_TEST(test_read_format_zip_zip64b)
 DEFINE_TEST(test_read_large)
+DEFINE_TEST(test_read_pax_empty_val_no_nl)
 DEFINE_TEST(test_read_pax_truncated)
 DEFINE_TEST(test_read_pax_xattr_rht_security_selinux)
 DEFINE_TEST(test_read_pax_xattr_schily)
@@ -522,9 +543,9 @@ DEFINE_TEST(test_ustar_filename_encoding_CP932_UTF8)
 DEFINE_TEST(test_ustar_filename_encoding_UTF16_win)
 DEFINE_TEST(test_ustar_filenames)
 DEFINE_TEST(test_warn_missing_hardlink_target)
-DEFINE_TEST(test_write_disk)
 DEFINE_TEST(test_write_disk_appledouble)
 DEFINE_TEST(test_write_disk_appledouble_zip)
+DEFINE_TEST(test_write_disk)
 DEFINE_TEST(test_write_disk_failures)
 DEFINE_TEST(test_write_disk_fixup)
 DEFINE_TEST(test_write_disk_hardlink)
@@ -533,11 +554,11 @@ DEFINE_TEST(test_write_disk_lookup)
 DEFINE_TEST(test_write_disk_mac_metadata)
 DEFINE_TEST(test_write_disk_no_hfs_compression)
 DEFINE_TEST(test_write_disk_perms)
-DEFINE_TEST(test_write_disk_secure)
 DEFINE_TEST(test_write_disk_secure744)
 DEFINE_TEST(test_write_disk_secure745)
 DEFINE_TEST(test_write_disk_secure746a)
 DEFINE_TEST(test_write_disk_secure746b)
+DEFINE_TEST(test_write_disk_secure)
 DEFINE_TEST(test_write_disk_secure_noabsolutepaths)
 DEFINE_TEST(test_write_disk_sparse)
 DEFINE_TEST(test_write_disk_symlink)
@@ -569,6 +590,7 @@ DEFINE_TEST(test_write_format_7zip_basic_deflate)
 DEFINE_TEST(test_write_format_7zip_basic_lzma1)
 DEFINE_TEST(test_write_format_7zip_basic_lzma2)
 DEFINE_TEST(test_write_format_7zip_basic_ppmd)
+DEFINE_TEST(test_write_format_7zip_basic_zstd)
 DEFINE_TEST(test_write_format_7zip_empty_archive)
 DEFINE_TEST(test_write_format_7zip_empty_files)
 DEFINE_TEST(test_write_format_7zip_large_bzip2)
@@ -577,6 +599,7 @@ DEFINE_TEST(test_write_format_7zip_large_deflate)
 DEFINE_TEST(test_write_format_7zip_large_lzma1)
 DEFINE_TEST(test_write_format_7zip_large_lzma2)
 DEFINE_TEST(test_write_format_7zip_large_ppmd)
+DEFINE_TEST(test_write_format_7zip_large_zstd)
 DEFINE_TEST(test_write_format_ar)
 DEFINE_TEST(test_write_format_cpio)
 DEFINE_TEST(test_write_format_cpio_empty)
@@ -585,22 +608,43 @@ DEFINE_TEST(test_write_format_cpio_odc)
 DEFINE_TEST(test_write_format_gnutar)
 DEFINE_TEST(test_write_format_gnutar_filenames)
 DEFINE_TEST(test_write_format_gnutar_linknames)
-DEFINE_TEST(test_write_format_iso9660)
 DEFINE_TEST(test_write_format_iso9660_boot)
+DEFINE_TEST(test_write_format_iso9660)
 DEFINE_TEST(test_write_format_iso9660_empty)
 DEFINE_TEST(test_write_format_iso9660_filename)
 DEFINE_TEST(test_write_format_iso9660_zisofs)
+DEFINE_TEST(test_write_format_mtree_absolute_path)
 DEFINE_TEST(test_write_format_mtree)
 DEFINE_TEST(test_write_format_mtree_no_leading_dotslash)
-DEFINE_TEST(test_write_format_mtree_absolute_path)
 DEFINE_TEST(test_write_format_mtree_classic)
 DEFINE_TEST(test_write_format_mtree_classic_indent)
 DEFINE_TEST(test_write_format_mtree_fflags)
 DEFINE_TEST(test_write_format_mtree_no_separator)
+DEFINE_TEST(test_write_format_mtree_digests_no_digests_set_no_data)
+DEFINE_TEST(test_write_format_mtree_digests_no_digests_set_empty_data)
+DEFINE_TEST(test_write_format_mtree_digests_no_digests_set_non_empty_data)
+DEFINE_TEST(test_write_format_mtree_digests_md5_digest_set_no_data)
+DEFINE_TEST(test_write_format_mtree_digests_md5_digest_set_empty_data)
+DEFINE_TEST(test_write_format_mtree_digests_md5_digest_set_non_empty_data)
+DEFINE_TEST(test_write_format_mtree_digests_rmd160_digest_set_no_data)
+DEFINE_TEST(test_write_format_mtree_digests_rmd160_digest_set_empty_data)
+DEFINE_TEST(test_write_format_mtree_digests_rmd160_digest_set_non_empty_data)
+DEFINE_TEST(test_write_format_mtree_digests_sha1_digest_set_no_data)
+DEFINE_TEST(test_write_format_mtree_digests_sha1_digest_set_empty_data)
+DEFINE_TEST(test_write_format_mtree_digests_sha1_digest_set_non_empty_data)
+DEFINE_TEST(test_write_format_mtree_digests_sha256_digest_set_no_data)
+DEFINE_TEST(test_write_format_mtree_digests_sha256_digest_set_empty_data)
+DEFINE_TEST(test_write_format_mtree_digests_sha256_digest_set_non_empty_data)
+DEFINE_TEST(test_write_format_mtree_digests_sha384_digest_set_no_data)
+DEFINE_TEST(test_write_format_mtree_digests_sha384_digest_set_empty_data)
+DEFINE_TEST(test_write_format_mtree_digests_sha384_digest_set_non_empty_data)
+DEFINE_TEST(test_write_format_mtree_digests_sha512_digest_set_no_data)
+DEFINE_TEST(test_write_format_mtree_digests_sha512_digest_set_empty_data)
+DEFINE_TEST(test_write_format_mtree_digests_sha512_digest_set_non_empty_data)
 DEFINE_TEST(test_write_format_mtree_quoted_filename)
 DEFINE_TEST(test_write_format_pax)
-DEFINE_TEST(test_write_format_raw)
 DEFINE_TEST(test_write_format_raw_b64)
+DEFINE_TEST(test_write_format_raw)
 DEFINE_TEST(test_write_format_shar_empty)
 DEFINE_TEST(test_write_format_tar)
 DEFINE_TEST(test_write_format_tar_empty)
@@ -611,13 +655,16 @@ DEFINE_TEST(test_write_format_warc)
 DEFINE_TEST(test_write_format_warc_empty)
 DEFINE_TEST(test_write_format_xar)
 DEFINE_TEST(test_write_format_xar_empty)
+DEFINE_TEST(test_write_format_zip64_stream)
 DEFINE_TEST(test_write_format_zip)
 DEFINE_TEST(test_write_format_zip64)
 DEFINE_TEST(test_write_format_zip_traditional_pkware_encryption)
 DEFINE_TEST(test_write_format_zip_winzip_aes128_encryption)
 DEFINE_TEST(test_write_format_zip_winzip_aes256_encryption)
-DEFINE_TEST(test_write_format_zip64_stream)
+DEFINE_TEST(test_write_format_zip_compression_bzip2)
+DEFINE_TEST(test_write_format_zip_compression_lzmaxz)
 DEFINE_TEST(test_write_format_zip_compression_store)
+DEFINE_TEST(test_write_format_zip_compression_zstd)
 DEFINE_TEST(test_write_format_zip_empty)
 DEFINE_TEST(test_write_format_zip_empty_zip64)
 DEFINE_TEST(test_write_format_zip_size_unset)
